"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.config = exports.LineConfig = void 0;
var _effect = require("effect");
/**
 * Configuration module for LINE API credentials
 *
 * @since 0.1.0
 */

/**
 * Configuration class for LINE API credentials
 * Contains the necessary authentication details for interacting with LINE APIs
 *
 * @since 0.1.0
 * @category models
 * @example
 * ```ts
 * const config = new LineConfig(
 *   "1234567890",
 *   Redacted.redact("secret"),
 *   Redacted.redact("token")
 * )
 * ```
 */
class LineConfig {
  channelId;
  channelSecret;
  channelAccessToken;
  constructor(channelId, channelSecret, channelAccessToken) {
    this.channelId = channelId;
    this.channelSecret = channelSecret;
    this.channelAccessToken = channelAccessToken;
  }
}
/**
 * Configuration for LINE Channel settings
 * Reads channel configuration from environment variables:
 * - LINE_CHANNEL_ID
 * - LINE_CHANNEL_SECRET
 * - LINE_CHANNEL_ACCESS_TOKEN
 *
 * @since 0.1.0
 * @category config
 */
exports.LineConfig = LineConfig;
const lineChannelConfig = /*#__PURE__*/_effect.Config.all([/*#__PURE__*/_effect.Config.withDescription(/*#__PURE__*/_effect.Config.string("CHANNEL_ID"), "LINE Channel ID"), /*#__PURE__*/_effect.Config.withDescription(/*#__PURE__*/_effect.Config.redacted(/*#__PURE__*/_effect.Config.string("CHANNEL_SECRET")), "LINE Channel Secret"), /*#__PURE__*/_effect.Config.withDescription(/*#__PURE__*/_effect.Config.redacted(/*#__PURE__*/_effect.Config.string("CHANNEL_ACCESS_TOKEN")), "LINE Channel Access Token")]);
/**
 * Main configuration for LINE API
 * Combines all LINE-related configurations and creates a LineConfig instance
 *
 * @since 0.1.0
 * @category config
 * @example
 * ```ts
 * const program = Effect.gen(function*($) {
 *   const lineConfig = yield* $(Config.unwrap(config))
 *   // Use lineConfig.channelId, lineConfig.channelSecret, etc.
 * })
 * ```
 */
const config = exports.config = /*#__PURE__*/_effect.Config.map(/*#__PURE__*/_effect.Config.nested(lineChannelConfig, "LINE"), ([channelId, channelSecret, channelAccessToken]) => new LineConfig(channelId, channelSecret, channelAccessToken));
//# sourceMappingURL=Config.js.map