/**
 * Configuration module for LINE API credentials
 *
 * @since 0.1.0
 */
import { Config } from "effect";
import type { Redacted } from "effect/Redacted";
/**
 * Configuration class for LINE API credentials
 * Contains the necessary authentication details for interacting with LINE APIs
 *
 * @since 0.1.0
 * @category models
 * @example
 * ```ts
 * const config = new LineConfig(
 *   "1234567890",
 *   Redacted.redact("secret"),
 *   Redacted.redact("token")
 * )
 * ```
 */
export declare class LineConfig {
    readonly channelId: string;
    readonly channelSecret: Redacted<string>;
    readonly channelAccessToken: Redacted<string>;
    constructor(channelId: string, channelSecret: Redacted<string>, channelAccessToken: Redacted<string>);
}
/**
 * Main configuration for LINE API
 * Combines all LINE-related configurations and creates a LineConfig instance
 *
 * @since 0.1.0
 * @category config
 * @example
 * ```ts
 * const program = Effect.gen(function*($) {
 *   const lineConfig = yield* $(Config.unwrap(config))
 *   // Use lineConfig.channelId, lineConfig.channelSecret, etc.
 * })
 * ```
 */
export declare const config: Config.Config<LineConfig>;
//# sourceMappingURL=Config.d.ts.map